package Acme::Alien::DontPanic::Install::Files;
use strict;
use warnings;
require Acme::Alien::DontPanic;
sub Inline { shift; Acme::Alien::DontPanic->Inline(@_) }
1;

=begin Pod::Coverage

  Inline

=cut
